@@ -221,7 +221,10 @@ export class ProfileTrace extends React.Component<
           }
           key={'frame-' + i}
           style={style}
-          title={Statistic.round(location.duration, 1) + 'ms'}
+          title={[
+            frame.name,
+            Statistic.round(location.duration, 1) + 'ms'
+          ].join('\n')}
         >
           {frame.name}
         </div>
@@ -608,7 +611,11 @@ interface IResultProps<T extends IOutcome> {
 function timingSummary(timing: ITimingOutcome): JSX.Element {
   return (
     <>
-      <div>
+      <div
+        title={
+          timing.reference.sort().map(Statistic.round).join(' ms\n') + ' ms'
+        }
+      >
         Reference: IQM:{' '}
         {Statistic.round(Statistic.interQuartileMean(timing.reference), 1)} ms,
         mean: {Statistic.round(Statistic.mean(timing.reference), 1)} ms, min:{' '}
@@ -634,14 +641,14 @@ function profilingSummary(profile: IProfilingOutcome): JSX.Element {
           Statistic.mean(first.traces.map(trace => trace.frames.length)),
           1
         )}
-        ,{' '}
+        .{' '}
         <span
           title={
             'Average recorderd: ' +
             Statistic.round(first.averageSampleInterval, 1)
           }
         >
-          . Sampling interval: {Statistic.round(first.samplingInterval, 1)} ms
+          Sampling interval: {Statistic.round(first.samplingInterval, 1)} ms
         </span>
       </div>
       <div>Total time: {formatTime(profile.totalTime)}</div>
@@ -958,7 +965,7 @@ export class BenchmarkLauncher extends React.Component<
       isRunning: true
     });
     try {
-      // copy to prevent user inadertedly changing what is being run
+      // copy to prevent user inadvertedly changing what is being run
       const scheduledBenchmarks = [...this.state.benchmarks];
       const scheduledScenarios = [...this.state.scenarios];
       const config = JSONExt.deepCopy(this._config as any) as IConfigValue;
